==> download-2023.1.27_11.3.40-root-(instance-1.us-central1-a.c.ayaingenieria.internal).tar.gz: resources/views/reportes/reportediarios.blade.php <==
<!DOCTYPE html>
<html lang="es">
<script src="{{ asset('js/chart.min.js') }}"></script>

<head>
    <meta charset="UTF-8">
    <meta http-equiv="X-UA-Compatible" content="IE=edge">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Document</title>
    <style>
        a {
            color: #553F92;
            text-decoration: none;
        }

        .btn_cta {
            border: 2px solid #553F92;
            padding: 13px 26px;
            border-radius: 24px;
            font-weight: bold;
            font-size: 18px;
        }

        .btn_cta:hover {
            background-color: #553F92;
            color: #ffffff;
        }
    </style>
</head>

<body style="background-color: #ffffff; text-align: center; border: solid grey 10px; margin: 0px; padding:0px; width:850px">
    <table width="700px">
        <tr>
            <td>
                @if ($proveedor == "kyocera")
                <img src="https://ayaingenieria.cl/aya/rendicion/img/logo/kyocera.png" width="200" height="100" style="text-align: right">
                @elseif($proveedor == "upgrade")
                <img src="https://ayaingenieria.cl/aya/rendicion/img/logo/logo_upgrade.png" width="200" height="100" style="text-align: right">
                @elseif($proveedor == "comtecglobal")
                <img src="https://ayaingenieria.cl/aya/rendicion/img/logo/comtecglobal_logo.jpeg" width="200" height="100" style="text-align: right">
                @else
                @endif
                <!--img src="https://ayaingenieria.cl/aya/rendicion/img/logo/kyocera.png" width="200" height="100" style="text-align: right"--> <br><br>
            </td>
            <td></td>
            <td>
                <img src="https://ayaingenieria.cl/aya/rendicion/img/logo/{{$logo_cliente ?? 'kyocera.png'}}" width="200" height="100" style="text-align: right">
            </td>
        </tr>
        <tr>
            <td colspan="3" style="padding:5px">
                <h2 style="text-align: center">AVANCE DIARIO ATENCIONES DE INSTALACIONES</h2>
            </td>
        </tr>
        <tr>
            <td colspan="3">
                <label for="" style="font-size: 25px;">Resumen</label>
            </td>
        </tr>
        <tr>
            <td></td>
        </tr>
        <tr>
            <td colspan="3">
                <p style="text-align: justify; font-size: 20px;"> Al cierre de la jornada hoy {{ \Carbon\Carbon::parse($fechaactual ?? '')->format('d/m/Y')}} se realizó la atención de un total de {{$total ?? ''}} instalaciones para el cliente {{$cliente ?? '' }} en su proyecto {{$cliente ?? ''}} gestionado por A&A Ingenieria Spa. </p>

            </td>
        </tr>
        <tr>
            <td style="text-align: center" colspan="3"><label style="font-size: 20px;">RECUENTO</label></td>
        </tr>
        <!-- <tr>  
    <td style="text-align: left" ><label style="font-size: 20px;">Equipos a implementar</label></td>
    <td style="text-align: left" ><label style="font-size: 20px;">Ejecutado</label></td>
    <td style="text-align: left" ><label style="font-size: 20px;">Canselados</label></td>
    <td style="text-align: left" ><label style="font-size: 20px;">En Revisionr</label></td>
    <td style="text-align: left" ><label style="font-size: 20px;">Reasignado</label></td>

</tr> -->

        <!-- <tr>  
   <td colspan="3"> 
    <table bgcolor="#002859"  style="color: #ffffff; padding: 10px;" height="" border="0" cellspacing="3" cellpadding="3">
        <tr><td>Equipos a implementar</td></tr>
        <tr> <td>100 - 100%</td></tr>
        <tr><td>Equipos a implementar</td></tr>
        <tr> <td>100 - 100%</td></tr>
        <tr><td>Equipos a implementar</td></tr>
        <tr> <td>100 - 100%</td></tr>
        <tr><td>Equipos a implementar</td></tr>
        <tr> <td>100 - 100%</td></tr>
        <tr><td>Equipos a implementar</td></tr>
        <tr> <td>100 - 100%</td></tr>
    </table>
   </td>
</tr> -->
        <!-- @php
$content;
$rechazado;
  $finalizados;
  $revisar;
   $pendientes;
  $cancelados;
@endphp -->

        <!-- 'asignados'=> $this->asignados,
            'rechazado'=> $this->rechazado,
            'finalizados'=> $this->finalizados,
            'revisar'=> $this->revisar,
            'pendientes'=> $this->pendientes,
            'cancelados'=> $this->cancelados, -->
        <tr>
            <td>
                <table bgcolor="#002859" style="color: #ffffff; padding: 10px; margin-left: 100px;" height="" border="0" cellspacing="3" cellpadding="3">
                    <tr>
                        <td>Equipos a implementar</td>
                    </tr>
                    <tr>
                        <td>{{$total ?? ''}} - 100%</td>
                    </tr>
                    @if($finalizados != 0)
                    <tr>
                        <td>Ejecutadas - </td>
                    </tr>
                    <tr>
                        <td>{{$finalizados ?? '' }} - @php echo number_format(($finalizados * 100) / $total,2) @endphp% </td>
                    </tr>
                    @endif
                    @if($asignados != 0)
                    <tr>
                        <td>Asignadas</td>
                    </tr>
                    <tr>
                        <td>{{$asignados}} - @php echo number_format(($asignados * 100) / $total,2) @endphp% </td>
                    </tr>
                    @endif
                    @if($cancelados != 0)
                    <tr>
                        <td>Canceladas</td>
                    </tr>
                    <tr>
                        <td>{{$cancelados}} - @php echo number_format(($cancelados * 100) / $total,2)@endphp% </td>
                    </tr>
                    @endif
                    @if($revisar != 0)
                    <tr>
                        <td>Revisión</td>
                    </tr>
                    <tr>
                        <td>{{$revisar}} - @php echo number_format(($revisar * 100) / $total,2) @endphp% </td>
                    </tr>
                    @endif
                    @if($pendientes != 0)
                    <tr>
                        <td>Pendientes</td>
                    </tr>
                    <tr>
                        <td>{{$pendientes}} - @php echo number_format(($pendientes * 100) / $total,2) @endphp% </td>
                    </tr>
                    @endif
                    @if($rechazado != 0)
                    <tr>
                        <td>Rechazadas</td>
                    </tr>
                    <tr>
                        <td>{{$rechazado}} - @php echo number_format(($rechazado * 100) / $total,2) @endphp% </td>
                    </tr>
                    @endif
                </table>
            </td>
            <td style="text-align: center">
                <img src="https://ayaingenieria.cl/aya/rendicion/fotos/fotos_reportes/{{$g1_nombre ?? 'g2_MiMi2022-07-19_8'}}.png" style="width: 270px; height: 270px;">
            </td>
            <td>
                <table bgcolor="#002859" style="color: #ffffff; padding: 10px; " height="" border="0" cellspacing="3" cellpadding="3">
                    <tr>
                        <td>Ciudad</td>
                        <td>Cantidad</td>
                    </tr>
                    @foreach ($insta_comunas as $los_datos)
                    <tr>
                        <td>{{$los_datos->sComuna}}</td>
                        <td>{{$los_datos->cantidad}}</td>
                    </tr>
                    @endforeach
                </table>
            </td>
        </tr>
        <tr>
            <td style="text-align: center" colspan="1.5"><label style="font-size: 20px;">MODELOS GESTIONADOS</label></td>
            <td style="text-align: center" colspan="1.5"><label style="font-size: 20px;">TIPO DE EQUIPO</label></td>
            <td style="text-align: center" colspan="1.5"><label style="font-size: 20px;">CARACTERISTICAS DE EQUIPO</label></td>
        </tr>
        <tr>
            <td>
                <img src="https://ayaingenieria.cl/aya/rendicion/fotos/fotos_reportes/{{$g2_nombre ?? 'g2_MiMi2022-07-19_8'}}.png" style="text-align: right; width: 270px; height: 270px;">
            </td>
            <td style="text-align: right">
                <img src="https://ayaingenieria.cl/aya/rendicion/fotos/fotos_reportes/{{$g5_nombre ?? 'mmmm'}}.png" style="text-align: right; width: 270px; height: 270px;">

            </td>
            <td style="text-align: center">
                <img src="https://ayaingenieria.cl/aya/rendicion/fotos/fotos_reportes/{{$g3_nombre ?? 'g2_MiMi2022-07-19_8'}}.png" style="text-align: right; width: 270px; height: 270px;">
            </td>
        </tr>
        <tr>
            <td colspan="3">
                <p style="text-align: justify; font-size: 20px;"> Equipos Salientes: {{$total_saliente ?? 0}}</p>
            </td>
        </tr>
        <tr>
            <td>
                @if(!empty($sal_comuna))
                <table bgcolor="#002859" style="color: #ffffff; padding: 10px; " height="" border="0" cellspacing="3" cellpadding="3">
                    <tr>
                        <td>Ciudad</td>
                        <td>Cantidad</td>
                    </tr>
                    @foreach ($sal_comuna as $los_datos)
                    <tr>
                        <td>{{$los_datos->sComuna}}</td>
                        <td>{{$los_datos->cantidad}}</td>
                    </tr>
                    @endforeach
                </table>
                @endif
            </td>
        </tr>
        <tr>
            <td style="text-align: center" colspan="3">
                <img src="https://ayaingenieria.cl/aya/rendicion/img/logo/aya.png" width="125" height="125" style="text-align: center">
            </td>
        </tr>
        <tr>
            <td style="text-align: right;font-size: 15px;" colspan="3">
                A&A ingenieria Spa. Todos los derechos reservados 2022.
            </td>
        </tr>
    </table>
    {{-- <img src="https://ayaingenieria.cl/aya/rendicion/fotos/fotos_reportes/arielass.png" width="200" height="100" style="text-align: right"> --}}
    {{-- {{ $nombre_g1}} --}}
    {{-- {{$content ?? }} --}}
    <div></div>
</body>

</html>

==> download-2023.8.1_13.1.34-root-(instance-1.us-central1-a.c.ayaingenieria.internal).tar.gz: resources/views/reportes/reportediarios.blade.php <==
<!DOCTYPE html>
<html lang="es">
<script src="{{ asset('js/chart.min.js') }}"></script>

<head>
    <meta charset="UTF-8">
    <meta http-equiv="X-UA-Compatible" content="IE=edge">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Document</title>
    <style>
        a {
            color: #553F92;
            text-decoration: none;
        }

        .btn_cta {
            border: 2px solid #553F92;
            padding: 13px 26px;
            border-radius: 24px;
            font-weight: bold;
            font-size: 18px;
        }

        .btn_cta:hover {
            background-color: #553F92;
            color: #ffffff;
        }
    </style>
</head>

<body style="background-color: #ffffff; text-align: center; border: solid grey 10px; margin: 0px; padding:0px; width:850px">
    <table width="700px">
        <tr>
            <td>
                @if ($proveedor == "kyocera")
                <img src="https://ayaingenieria.cl/aya/rendicion/img/logo/kyocera.png" width="200" height="100" style="text-align: right">
                @elseif($proveedor == "upgrade")
                <img src="https://ayaingenieria.cl/aya/rendicion/img/logo/logo_upgrade.png" width="200" height="100" style="text-align: right">
                @elseif($proveedor == "comtecglobal")
                <img src="https://ayaingenieria.cl/aya/rendicion/img/logo/comtecglobal_logo.jpeg" width="200" height="100" style="text-align: right">
                @else
                @endif
                <!--img src="https://ayaingenieria.cl/aya/rendicion/img/logo/kyocera.png" width="200" height="100" style="text-align: right"--> <br><br>
            </td>
            <td></td>
            <td>
                <img src="https://ayaingenieria.cl/aya/rendicion/img/logo/{{$logo_cliente ?? 'kyocera.png'}}" width="200" height="100" style="text-align: right">
            </td>
        </tr>
        <tr>
            <td colspan="3" style="padding:5px">
                <h2 style="text-align: center">AVANCE DIARIO ATENCIONES DE INSTALACIONES</h2>
            </td>
        </tr>
        <tr>
            <td colspan="3">
                <label for="" style="font-size: 25px;">Resumen</label>
            </td>
        </tr>
        <tr>
            <td></td>
        </tr>
        <tr>
            <td colspan="3">
                <p style="text-align: justify; font-size: 20px;"> Al cierre de la jornada hoy {{ \Carbon\Carbon::parse($fechaactual ?? '')->format('d/m/Y')}} se realizó la atención de un total de {{$total ?? ''}} instalaciones para el cliente {{$cliente ?? '' }} en su proyecto {{$cliente ?? ''}} gestionado por A&A Ingenieria Spa. </p>

            </td>
        </tr>
        <tr>
            <td style="text-align: center" colspan="3"><label style="font-size: 20px;">RECUENTO</label></td>
        </tr>
        <!-- <tr>  
    <td style="text-align: left" ><label style="font-size: 20px;">Equipos a implementar</label></td>
    <td style="text-align: left" ><label style="font-size: 20px;">Ejecutado</label></td>
    <td style="text-align: left" ><label style="font-size: 20px;">Canselados</label></td>
    <td style="text-align: left" ><label style="font-size: 20px;">En Revisionr</label></td>
    <td style="text-align: left" ><label style="font-size: 20px;">Reasignado</label></td>

</tr> -->

        <!-- <tr>  
   <td colspan="3"> 
    <table bgcolor="#002859"  style="color: #ffffff; padding: 10px;" height="" border="0" cellspacing="3" cellpadding="3">
        <tr><td>Equipos a implementar</td></tr>
        <tr> <td>100 - 100%</td></tr>
        <tr><td>Equipos a implementar</td></tr>
        <tr> <td>100 - 100%</td></tr>
        <tr><td>Equipos a implementar</td></tr>
        <tr> <td>100 - 100%</td></tr>
        <tr><td>Equipos a implementar</td></tr>
        <tr> <td>100 - 100%</td></tr>
        <tr><td>Equipos a implementar</td></tr>
        <tr> <td>100 - 100%</td></tr>
    </table>
   </td>
</tr> -->
        <!-- @php
$content;
$rechazado;
  $finalizados;
  $revisar;
   $pendientes;
  $cancelados;
@endphp -->

        <!-- 'asignados'=> $this->asignados,
            'rechazado'=> $this->rechazado,
            'finalizados'=> $this->finalizados,
            'revisar'=> $this->revisar,
            'pendientes'=> $this->pendientes,
            'cancelados'=> $this->cancelados, -->
        <tr>
            <td>
                <table bgcolor="#002859" style="color: #ffffff; padding: 10px; margin-left: 100px;" height="" border="0" cellspacing="3" cellpadding="3">
                    <tr>
                        <td>Equipos a implementar</td>
                    </tr>
                    <tr>
                        <td>{{$total ?? ''}} - 100%</td>
                    </tr>
                    @if($finalizados != 0)
                    <tr>
                        <td>Ejecutadas - </td>
                    </tr>
                    <tr>
                        <td>{{$finalizados ?? '' }} - @php echo number_format(($finalizados * 100) / $total,2) @endphp% </td>
                    </tr>
                    @endif
                    @if($asignados != 0)
                    <tr>
                        <td>Asignadas</td>
                    </tr>
                    <tr>
                        <td>{{$asignados}} - @php echo number_format(($asignados * 100) / $total,2) @endphp% </td>
                    </tr>
                    @endif
                    @if($cancelados != 0)
                    <tr>
                        <td>Canceladas</td>
                    </tr>
                    <tr>
                        <td>{{$cancelados}} - @php echo number_format(($cancelados * 100) / $total,2)@endphp% </td>
                    </tr>
                    @endif
                    @if($revisar != 0)
                    <tr>
                        <td>Revisión</td>
                    </tr>
                    <tr>
                        <td>{{$revisar}} - @php echo number_format(($revisar * 100) / $total,2) @endphp% </td>
                    </tr>
                    @endif
                    @if($pendientes != 0)
                    <tr>
                        <td>Pendientes</td>
                    </tr>
                    <tr>
                        <td>{{$pendientes}} - @php echo number_format(($pendientes * 100) / $total,2) @endphp% </td>
                    </tr>
                    @endif
                    @if($rechazado != 0)
                    <tr>
                        <td>Rechazadas</td>
                    </tr>
                    <tr>
                        <td>{{$rechazado}} - @php echo number_format(($rechazado * 100) / $total,2) @endphp% </td>
                    </tr>
                    @endif
                </table>
            </td>
            <td style="text-align: center">
                <img src="https://ayaingenieria.cl/aya/rendicion/fotos/fotos_reportes/{{$g1_nombre ?? 'g2_MiMi2022-07-19_8'}}.png" style="width: 270px; height: 270px;">
            </td>
            <td>
                <table bgcolor="#002859" style="color: #ffffff; padding: 10px; " height="" border="0" cellspacing="3" cellpadding="3">
                    <tr>
                        <td>Ciudad</td>
                        <td>Cantidad</td>
                    </tr>
                    @foreach ($insta_comunas as $los_datos)
                    <tr>
                        <td>{{$los_datos->sComuna}}</td>
                        <td>{{$los_datos->cantidad}}</td>
                    </tr>
                    @endforeach
                </table>
            </td>
        </tr>
        <tr>
            <td style="text-align: center" colspan="1.5"><label style="font-size: 20px;">MODELOS GESTIONADOS</label></td>
            <td style="text-align: center" colspan="1.5"><label style="font-size: 20px;">TIPO DE EQUIPO</label></td>
            <td style="text-align: center" colspan="1.5"><label style="font-size: 20px;">CARACTERISTICAS DE EQUIPO</label></td>
        </tr>
        <tr>
            <td>
                <img src="https://ayaingenieria.cl/aya/rendicion/fotos/fotos_reportes/{{$g2_nombre ?? 'g2_MiMi2022-07-19_8'}}.png" style="text-align: right; width: 270px; height: 270px;">
            </td>
            <td style="text-align: right">
                <img src="https://ayaingenieria.cl/aya/rendicion/fotos/fotos_reportes/{{$g5_nombre ?? 'mmmm'}}.png" style="text-align: right; width: 270px; height: 270px;">

            </td>
            <td style="text-align: center">
                <img src="https://ayaingenieria.cl/aya/rendicion/fotos/fotos_reportes/{{$g3_nombre ?? 'g2_MiMi2022-07-19_8'}}.png" style="text-align: right; width: 270px; height: 270px;">
            </td>
        </tr>
        <tr>
            <td colspan="3">
                <p style="text-align: justify; font-size: 20px;"> Equipos Salientes: {{$total_saliente ?? 0}}</p>
            </td>
        </tr>
        <tr>
            <td>
                @if(!empty($sal_comuna))
                <table bgcolor="#002859" style="color: #ffffff; padding: 10px; " height="" border="0" cellspacing="3" cellpadding="3">
                    <tr>
                        <td>Ciudad</td>
                        <td>Cantidad</td>
                    </tr>
                    @foreach ($sal_comuna as $los_datos)
                    <tr>
                        <td>{{$los_datos->sComuna}}</td>
                        <td>{{$los_datos->cantidad}}</td>
                    </tr>
                    @endforeach
                </table>
                @endif
            </td>
        </tr>
        <tr>
            <td style="text-align: center" colspan="3">
                <img src="https://ayaingenieria.cl/aya/rendicion/img/logo/aya.png" width="125" height="125" style="text-align: center">
            </td>
        </tr>
        <tr>
            <td style="text-align: right;font-size: 15px; color:red" colspan="3">
                NO RESPONDER ESTE EMAIL, CORREO AUTOMATIZADO.
            </td>
        </tr>
        <tr>
            <td style="text-align: right;font-size: 15px;" colspan="3">
                A&A ingenieria Spa. Todos los derechos reservados 2022.
            </td>
        </tr>
    </table>
    {{-- <img src="https://ayaingenieria.cl/aya/rendicion/fotos/fotos_reportes/arielass.png" width="200" height="100" style="text-align: right"> --}}
    {{-- {{ $nombre_g1}} --}}
    {{-- {{$content ?? }} --}}
    <div></div>
</body>

</html>
